@@ -46,6 +46,16 @@ feature.add_command(exec)
 def remote(ctx):
   pass
 
-ConfigDecorator(remote, settings, 'cli.features.remote').decorate()
+def __handle_enable_before_action():
+  api_key = settings.remote.api_key
+  if not api_key or len(api_key) == 0:
+    api_key = click.prompt('Please enter your API key', type=str)
+    settings.remote.api_key = api_key
+
+ConfigDecorator(remote, settings, 'cli.features.remote', {
+  'enable': {
+    'before_action': __handle_enable_before_action
+  }
+}).decorate()
 
 feature.add_command(remote)
\ No newline at end of file
