@@ -1,45 +1,54 @@
-import jmespath
-
-
-from .visitor import TreeInterpreter, Visitor
-
-# Monkey patch jmespath with replacement functionality
-jmespath.parser.visitor.Vistor = Visitor
-jmespath.parser.visitor.TreeInterpreter = TreeInterpreter
-
 import pdb
 
 from requests import Response
 from typing import Callable, Dict, List, Union
 
+from stoobly_agent.app.proxy.replay.alias_resolver import AliasResolver
 from stoobly_agent.app.cli.helpers.tabulate_print_service import tabulate_print
-from stoobly_agent.config.constants import custom_headers
+from stoobly_agent.config.constants import alias_resolve_strategy, custom_headers
 from stoobly_agent.app.models.schemas.request import Request
 from stoobly_agent.app.proxy.replay.body_parser_service import decode_response
-from stoobly_agent.app.proxy.replay.context import ReplayContext
-from stoobly_agent.app.proxy.replay.rewrite_params_service import build_id_to_alias_map, resolve_alias, rewrite_params
+from stoobly_agent.app.cli.helpers.context import ReplayContext
+from stoobly_agent.app.proxy.replay.rewrite_params_service import build_id_to_alias_map, rewrite_params
 from stoobly_agent.lib.api.endpoints_resource import EndpointsResource
 from stoobly_agent.lib.api.interfaces.endpoints import Alias, EndpointShowResponse, RequestComponentName
 from stoobly_agent.lib.logger import Logger, bcolors
 from stoobly_agent.lib.orm.trace import Trace
 from stoobly_agent.lib.orm.trace_alias import TraceAlias
+from stoobly_agent.lib.orm.trace_request import TraceRequest
+from stoobly_agent.lib.utils import jmespath
 
 AliasMap = Dict[str, RequestComponentName]
 
 class TraceContext:
 
-  def __init__(self, endpoints_resource: EndpointsResource, trace):
+  def __init__(self, endpoints_resource: EndpointsResource, trace = None):
     self.__endpoints_resource = endpoints_resource
 
     self.__trace = trace or Trace.create()
     Logger.instance().debug(f"Using trace {self.__trace.id}")
 
+    self.__alias_resolver = AliasResolver(self.__trace, alias_resolve_strategy.NONE)
+
     self.__requests: List[Request] = []
 
+  @property
+  def alias_resolve_strategy(self):
+    return self.__alias_resolver.strategy
+
+  @alias_resolve_strategy.setter
+  def alias_resolve_strategy(self, v):
+    if v:
+      self.__alias_resolver.strategy = v
+
   @property
   def trace(self):
     return self.__trace
 
+  @property
+  def endpoints_resource(self):
+    return self.__endpoints_resource
+
   def with_replay_context(self, context: ReplayContext, replay: Callable[[], Response]): 
     request = context.request
     endpoint = None
@@ -50,26 +59,31 @@ class TraceContext:
     if endpoint:
       Logger.instance().debug(f"\tMatched Endpoint: {endpoint}")
 
-      self.__rewrite_request(request, endpoint)
+      if self.alias_resolve_strategy != alias_resolve_strategy.NONE:
+        self.__rewrite_request(request, endpoint)
+
+    trace_request = TraceRequest.create(trace_id=self.__trace.id)
 
     # Set trace id for request
     headers = request.headers
     headers[custom_headers.TRACE_ID] = str(self.trace.id)
+    headers[custom_headers.TRACE_REQUEST_ID] = str(trace_request.id)
     request.headers = headers
 
     # Replay request
     response = replay(context)
 
     if endpoint:
-      self.__create_trace_aliases(response, endpoint)
+      self.__create_trace_aliases(trace_request, response, endpoint)
 
     self.__requests.append((request, response))
 
-  def create_trace_alias(self, alias_name, value):
+  def create_trace_alias(self, alias_name, value, trace_request = None):
     trace_alias = TraceAlias.create(
       name=alias_name,
       value=value,
-      trace_id=self.__trace.id
+      trace_id=self.__trace.id,
+      trace_request_id=trace_request.id if trace_request else None
     )
     Logger.instance().info(f"{bcolors.OKGREEN}Resolved {trace_alias.name}: {value}{bcolors.ENDC}")
     return trace_alias
@@ -107,7 +121,7 @@ class TraceContext:
       if not trace_alias:
         continue
 
-      path_segment_strings[position] = trace_alias.value
+      path_segment_strings[position] = str(trace_alias.value)
 
     request.path = '/' + '/'.join(path_segment_strings)
 
@@ -130,15 +144,16 @@ class TraceContext:
   ):
     body_params = request.body_params
 
-    rewrite_params(
-      body_params, 
-      body_param_names, 
-      id_to_alias, 
-      self.trace,
-      lambda trace_alias, v: self.__assign_trace_alias(trace_alias, v)
-    )
+    if isinstance(body_params, list) or isinstance(body_params, dict):
+      rewrite_params(
+        body_params, 
+        body_param_names, 
+        id_to_alias, 
+        self.__alias_resolver,
+        handle_after_replace=lambda trace_alias, v: self.__assign_trace_alias(trace_alias, v)
+      )
 
-    request.body_params = body_params
+      request.body_params = body_params
 
   def __rewrite_components(self, components, component_names, id_to_alias: AliasMap):
     visited = {}
@@ -156,11 +171,11 @@ class TraceContext:
       new_values = []
       current_values = components.get_all(name)
       if len(current_values) == 0:
-        trace_aliases = resolve_alias(_alias['name'], None)
-        if trace_aliases.is_empty():
+        trace_alias = self.__alias_resolver.resolve_alias(_alias['name'], None)
+
+        if not trace_alias:
           continue
 
-        trace_alias = trace_aliases.pop()
         new_values.append(trace_alias.value)
       else:
         # Remove all values for the key, name
@@ -180,7 +195,7 @@ class TraceContext:
       for new_value in new_values:
         components.add(name, new_value)
 
-  def __create_trace_aliases(self, response: Response, endpoint: EndpointShowResponse):
+  def __create_trace_aliases(self, trace_request: TraceRequest, response: Response, endpoint: EndpointShowResponse):
     '''
     1. Parse all aliased properties from response
     2. Create TraceAlias records for each parsed aliased propert
@@ -208,23 +223,20 @@ class TraceContext:
 
       for value in values:  
         if _alias and value:
-          self.create_trace_alias(_alias['name'], value) 
+          self.create_trace_alias(_alias['name'], value, trace_request) 
 
-  def __resolve_and_assign_alias(self, alias_name: str, value: list) -> Union[TraceAlias, None]:
-    trace_aliases = resolve_alias(self.trace, alias_name, value)
-    if trace_aliases.is_empty():
-      return
-      
-    trace_alias = trace_aliases.pop()
-    self.__assign_trace_alias(trace_alias, value)
+  def __resolve_and_assign_alias(self, alias_name: str, value) -> Union[TraceAlias, None]:
+    trace_alias = self.__alias_resolver.resolve_alias(alias_name, value)
 
-    return trace_alias
+    if trace_alias:
+      self.__assign_trace_alias(trace_alias, value)
+
+      return trace_alias
 
   def __assign_trace_alias(self, trace_alias: TraceAlias, value):
     if not trace_alias.assigned_to:
       trace_alias.assigned_to = value
       trace_alias.save()
-
       Logger.instance().info(f"{bcolors.OKBLUE}Assigned {trace_alias.name}: {value} -> {trace_alias.value}{bcolors.ENDC}")
 
   def __query_resolves_response(self, query: str, response: Union[list, dict]) -> list:
