@@ -1,5 +1,6 @@
 import os
 import pdb
+import tempfile
 
 class DataDir:
     DATA_DIR_NAME = '.stoobly'
@@ -41,13 +42,14 @@ class DataDir:
         db_dir_path = os.path.join(self.path, 'db')
 
         if not os.path.exists(db_dir_path):
-            os.mkdir(db_dir_path, exist_ok=True)
+            os.mkdir(db_dir_path)
 
         return db_dir_path
 
     @property
     def tmp_db_file_path(self):
-        return os.path.join('/', 'tmp', self.DB_FILE_NAME)
+        tmp = tempfile.NamedTemporaryFile(delete=False)
+        return tmp.name
 
     @property
     def db_file_path(self):
@@ -55,4 +57,4 @@ class DataDir:
 
     @property
     def settings_file_path(self):
-        return os.path.join(self.path, 'settings.yml')
\ No newline at end of file
+        return os.path.join(self.path, 'settings.yml')
