@@ -1,6 +1,6 @@
 from .endpoints import EndpointsIndexQueryParams
 from .pagination_query_params import PaginationQueryParams
-from .projects import ProjectCreateParams, ProjectShowResponse, ProjectsIndexQueryParams, ProjectsIndexResponse 
+from .projects import ProjectCreateParams, ProjectDetails, ProjectShowResponse, ProjectsIndexQueryParams, ProjectsIndexResponse
 from .report_show_response import ReportShowResponse
 from .request_create_params import RequestCreateParams
 from .request_show_query_params import RequestShowQueryParams
@@ -11,4 +11,4 @@ from .response_show_response import ResponseShowResponse
 from .scenarios import ScenarioShowResponse, ScenariosIndexResponse
 from .tests import TestCreateParams, TestShowResponse, TestsIndexQueryParams, TestsIndexResponse
 from .traces import TraceShowResponse
-from .users import UserProfileResponse
\ No newline at end of file
+from .users import UserProfileResponse
