@@ -1,8 +1,20 @@
 import logging
+import logging.config
 import os
 
 from stoobly_agent.config.constants.env_vars import LOG_LEVEL
 
+class bcolors:
+    HEADER = '\033[95m'
+    OKBLUE = '\033[94m'
+    OKCYAN = '\033[96m'
+    OKGREEN = '\033[92m'
+    WARNING = '\033[93m'
+    FAIL = '\033[91m'
+    ENDC = '\033[0m'
+    BOLD = '\033[1m'
+    UNDERLINE = '\033[4m'
+
 class Logger:
     _instance = None
 
@@ -17,6 +29,7 @@ class Logger:
             log_level = os.getenv(LOG_LEVEL) or ''
 
             if log_level.lower() == 'debug':
+                logging.config.dictConfig({'disable_existing_loggers': True, 'version': 1})
                 logging.basicConfig(level=logging.DEBUG)
             elif log_level.lower() == 'warning':
                 logging.basicConfig(level=logging.WARNING)
@@ -25,15 +38,4 @@ class Logger:
             else:
                 logging.basicConfig(level=logging.INFO)
 
-        return logging
-
-class bcolors:
-    HEADER = '\033[95m'
-    OKBLUE = '\033[94m'
-    OKCYAN = '\033[96m'
-    OKGREEN = '\033[92m'
-    WARNING = '\033[93m'
-    FAIL = '\033[91m'
-    ENDC = '\033[0m'
-    BOLD = '\033[1m'
-    UNDERLINE = '\033[4m'
\ No newline at end of file
+        return logging
\ No newline at end of file
